@@ -1,24 +1,13 @@
 /*
- *  kcmhistory.cpp
- *  Copyright (c) 2000,2001 Carsten Pfeiffer <pfeiffer@kde.org>
- *  Copyright (c) 2002 Stephan Binner <binner@kde.org>
- *
- *  based on kcmtaskbar.cpp
- *  Copyright (c) 2000 Kurt Granroth <granroth@kde.org>
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- */
+    kcmhistory.cpp
+    SPDX-FileCopyrightText: 2000, 2001 Carsten Pfeiffer <pfeiffer@kde.org>
+    SPDX-FileCopyrightText: 2002 Stephan Binner <binner@kde.org>
+
+    based on kcmtaskbar.cpp
+    SPDX-FileCopyrightText: 2000 Kurt Granroth <granroth@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 // Own
 #include "kcmhistory.h"
@@ -32,7 +21,7 @@
 // KDE
 #include <KConfig>
 #include <KConfigGroup>
-#include <KFontChooser>
+// #include <KFontChooser>
 #include <KLocalizedString>
 #include <kmessagebox.h>
 #include <KPluginFactory>
@@ -42,10 +31,7 @@
 
 // Local
 
-K_PLUGIN_FACTORY(KCMHistoryFactory,
-                 registerPlugin<HistorySidebarConfig>();
-                )
-K_EXPORT_PLUGIN(KCMHistoryFactory("kcmhistory"))
+K_PLUGIN_CLASS_WITH_JSON(HistorySidebarConfig, "kcmhistory.json")
 
 HistorySidebarConfig::HistorySidebarConfig(QWidget *parent, const QVariantList &)
     : KCModule(parent, QVariantList())
